@@ -7,9 +7,7 @@ use vars qw(@EXPORT);
 
 @EXPORT = qw(note);
 
-sub import {
-    goto &Exporter::import;
-}
+*import = \&Exporter::import;
 
 my $realnode = UUID::_realnode();
 substr $realnode, 0, 24, '' if $realnode;
