@@ -29,16 +29,23 @@ extern "C" {
 
 /* called at boot */
 void uu_clock_init(pUCXT) {
+  UV ptod[2];
+
+  /* gettimeofday(&tv, 0); */
+  (*myU2time)(aTHX_ (UV*)&ptod);
+  last.tv_sec  = (long)ptod[0];
+  last.tv_usec = (long)ptod[1];
+
+  cc_rand16(aUCXT, &clock_seq);
+  clock_seq &= 0x3fff;
+
   state_fd       = -3;
   state_f        = NULL;
   pathlen.path   = NULL;
   pathlen.len    = 0;
   adjustment     = 0;
-  last.tv_sec    = 0;
-  last.tv_usec   = 0;
   prev_clock_reg = 0;
   defer_100ns    = 0;
-  /* clock_seq uninit */
 }
 
 void uu_clock_getpath(pUCXT, struct_pathlen_t *sp) {
@@ -127,29 +134,17 @@ IV uu_clock(pUCXT, U64 *ret_clock_reg, U16 *ret_clock_seq) {
   tv.tv_sec  = (long)ptod[0];
   tv.tv_usec = (long)ptod[1];
 
-  if ((last.tv_sec == 0) && (last.tv_usec == 0)) {
-    cc_rand16(aUCXT, &clock_seq);
-    clock_seq &= 0x3fff;
-
-    last.tv_sec  = tv.tv_sec - 1;
-    last.tv_usec = tv.tv_usec;
-  }
-
-  if ((tv.tv_sec < last.tv_sec) || ((tv.tv_sec == last.tv_sec) && (tv.tv_usec < last.tv_usec))) {
-    clock_seq = (clock_seq+1) & 0x3fff;
-    adjustment = 0;
-    last = tv;
-  }
-  else if ((tv.tv_sec == last.tv_sec) && (tv.tv_usec == last.tv_usec)) {
-    if (adjustment >= MAX_ADJUSTMENT) {
+  if ((tv.tv_sec == last.tv_sec) && (tv.tv_usec == last.tv_usec)) {
+    /* same time as last */
+    if (++adjustment >= MAX_ADJUSTMENT) {
       clock_seq = (clock_seq+1) & 0x3fff;
       adjustment = 0;
     }
-    else {
-      adjustment++;
-    }
   }
   else {
+    /* time changed */
+    if ((tv.tv_sec == last.tv_sec) && (tv.tv_usec < last.tv_usec) || (tv.tv_sec < last.tv_sec))
+        clock_seq = (clock_seq+1) & 0x3fff; /* time moved backward */
     adjustment = 0;
     last = tv;
   }
